unit textfm;

// Copyright  2000 by Ziff-Davis, Inc.
// Written by Neil J. Rubenking

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls;

type
  TTextForm = class(TForm)
    btnSetFont  : TButton;
    lblFont     : TLabel;
    ebSample    : TEdit;
    btnOK       : TButton;
    btnCancel   : TButton;
    fFD         : TFontDialog;
    procedure FormCreate      (Sender: TObject);
    procedure FormDestroy     (Sender: TObject);
    procedure FormActivate    (Sender: TObject);
    procedure btnSetFontClick (Sender: TObject);
  private
    { Private declarations }
    iniName : String;
    procedure ShowFont;
  public
    { Public declarations }
  end;

var
  TextForm: TTextForm;

implementation

uses allfuncs, inifiles;

{$R *.DFM}

procedure TTextForm.FormCreate(Sender: TObject);
begin
  iniName := ChangeFileExt(Application.ExeName, '.INI');
  GetPosFmIni(IniName, Self, False);
  WITH TIniFile.Create(iniName) DO
  try
    fFD.Font.Name  := ReadString('Font', 'Typeface',
      'MS Sans Serif');
    fFD.Font.Size  := ReadInteger('Font', 'Size', 8);
    fFD.Font.Style := TFontStyles(Byte(
      ReadInteger('Font', 'Style', 0)));
  finally
    Free;
  end;
  ShowFont;
end;

procedure TTextForm.FormDestroy(Sender: TObject);
begin
  WITH TIniFile.Create(iniName) DO
  try
    WriteString ('Font', 'Typeface', fFD.Font.Name);
    WriteInteger('Font', 'Size', fFD.Font.Size);
    WriteInteger('Font', 'Style', Byte(fFD.Font.Style));
  finally
    Free;
  end;
  SetPosToIni(IniName, Self, False);
end;

procedure TTextForm.FormActivate(Sender: TObject);
begin
  ebSample.SelectAll;
  ebSample.SetFocus;
end;

procedure TTextForm.btnSetFontClick(Sender: TObject);
begin
  IF fFD.Execute THEN ShowFont;
end;

procedure TTextForm.ShowFont;
  function StringFor(T : TFontStyles) : String;
  begin
    Result := '';
    IF fsBold      IN T THEN Result := Result + ', bold';
    IF fsItalic    IN T THEN Result := Result + ', ital';
    IF fsunderline IN T THEN Result := Result + ', und';
    IF fsstrikeout IN T THEN Result := Result + ', stk';
  end;

begin
  lblFont.Caption := Format('%s, %d-point%s:',
    [fFD.Font.Name, fFD.Font.Size, StringFor(fFD.Font.Style)]);
  ebSample.Font     := fFD.Font;
  btnOK.Top         := ebSample.Top + ebSample.Height + 7;
  btnCancel.Top     := btnOK.Top;
  Self.ClientHeight := btnOK.Top + btnOK.height + 4;
end;


end.
